@@ -3,14 +3,24 @@ package org.gcube.portlets.widgets.ckandatapublisherwidget.client;
 import java.util.ArrayList;
 import java.util.List;
 
-import org.gcube.portlets.widgets.ckandatapublisherwidget.client.ui.CreateDatasetForm;
-import org.gcube.portlets.widgets.ckandatapublisherwidget.client.ui.MetaDataFieldSkeleton;
-import org.gcube.portlets.widgets.ckandatapublisherwidget.shared.DataType;
-import org.gcube.portlets.widgets.ckandatapublisherwidget.shared.MetadataFieldWrapper;
+import org.gcube.portlets.widgets.ckandatapublisherwidget.client.openlayerwidget.GeoJsonAreaSelectionDialog;
+import org.gcube.portlets.widgets.ckandatapublisherwidget.client.ui.TwinColumnSelection.TwinColumnSelectionMainPanel;
+import org.gcube.portlets.widgets.ckandatapublisherwidget.client.ui.form.CreateDatasetForm;
+import org.gcube.portlets.widgets.ckandatapublisherwidget.client.ui.metadata.MetaDataFieldSkeleton;
+import org.gcube.portlets.widgets.ckandatapublisherwidget.shared.ResourceElementBean;
+import org.gcube.portlets.widgets.ckandatapublisherwidget.shared.metadata.DataTypeWrapper;
+import org.gcube.portlets.widgets.ckandatapublisherwidget.shared.metadata.MetadataFieldWrapper;
+import org.gcube.portlets.widgets.openlayerbasicwidgets.client.widgets.GeometryType;
 
 import com.github.gwtbootstrap.client.ui.Button;
+import com.github.gwtbootstrap.client.ui.ListBox;
+import com.github.gwtbootstrap.client.ui.Modal;
 import com.google.gwt.core.client.EntryPoint;
+import com.google.gwt.core.client.Scheduler;
+import com.google.gwt.core.client.Scheduler.ScheduledCommand;
 import com.google.gwt.core.shared.GWT;
+import com.google.gwt.dom.client.SelectElement;
+import com.google.gwt.dom.client.Style.Unit;
 import com.google.gwt.event.dom.client.ClickEvent;
 import com.google.gwt.event.dom.client.ClickHandler;
 import com.google.gwt.event.shared.HandlerManager;
@@ -34,9 +44,57 @@ public class CKanMetadataPublisher implements EntryPoint {
 	public void onModuleLoad() {
 
 		// remove comment to the below line for testing the widget
-		//startExample();
-		//testMetadata();
-		//testSelectionPanel();
+		// startExample();
+		// testMetadata();
+		// testSelectionPanel();
+		// testHideOption();
+		// startTwinColumn();
+
+		//testSpatialWidget();
+
+	}
+
+	private void testSpatialWidget(){
+		//Use AreaSelectionDialog(GeometryType.Point)
+		//for specific Geometry
+
+		Scheduler.get().scheduleDeferred(new ScheduledCommand() {
+			@Override
+			public void execute() {
+				GeoJsonAreaSelectionDialog dialog=new GeoJsonAreaSelectionDialog(GeometryType.LineString);
+				dialog.show();
+			}
+		});
+
+
+		//RootPanel.get("ckan-metadata-publisher-div").add(listBox);
+	}
+
+	@SuppressWarnings("unused")
+	private void testHideOption() {
+
+		ListBox listBox = new ListBox(true);
+		listBox.addItem("A");
+		listBox.addItem("B");
+		listBox.addItem("C");
+		listBox.addItem("D");
+		listBox.addItem("E");
+		listBox.addItem("F");
+
+		List<String> toHide = new ArrayList<String>();
+		toHide.add("A");
+		toHide.add("D");
+
+		RootPanel.get("ckan-metadata-publisher-div").add(listBox);
+		SelectElement se = listBox.getElement().cast();
+
+		// hide
+		for (int i = 0; i < listBox.getItemCount(); i++) {
+			if(toHide.contains(listBox.getItemText(i))){
+				GWT.log("to hide " + listBox.getItemText(i));
+				se.getOptions().getItem(i).getStyle().setProperty("display", "none");
+			}
+		}
 
 	}
 
@@ -55,9 +113,9 @@ public class CKanMetadataPublisher implements EntryPoint {
 		//		listLeft.add(new ResourceElementBean(null, "File I", false, null, "File I"));
 		//
 		//		// test with folder and childs
-		//		ArrayList<ResourceElementBean> childrenOfA = new ArrayList<ResourceElementBean>(); 
+		//		ArrayList<ResourceElementBean> childrennameOfA = new ArrayList<ResourceElementBean>();
 		//		ArrayList<ResourceElementBean> childrenOfW = new ArrayList<ResourceElementBean>();
-		//		
+		//
 		//		ResourceElementBean elementA = new ResourceElementBean(null, "Folder A", true, childrenOfA, "Folder A");
 		//		childrenOfA.add(new ResourceElementBean(elementA, "File X", false, null, "Folder A:File X"));
 		//		childrenOfA.add(new ResourceElementBean(elementA, "File Y", false, null, "Folder A:File Y"));
@@ -68,6 +126,8 @@ public class CKanMetadataPublisher implements EntryPoint {
 		//		childrenOfW.add(new ResourceElementBean(elementW, "File J", false, null, "Folder A:File W: File J"));
 		//		listLeft.add(elementA);
 		//
+
+
 		//		String folderId = "e87bfc7d-4fb0-4795-9c79-0c495500ca9c";
 		//		ckanServices.getTreeFolder(folderId, new AsyncCallback<ResourceElementBean>() {
 		//
@@ -86,7 +146,6 @@ public class CKanMetadataPublisher implements EntryPoint {
 		//
 		//			}
 		//		});
-
 	}
 
 	@SuppressWarnings("unused")
@@ -102,8 +161,12 @@ public class CKanMetadataPublisher implements EntryPoint {
 		// checkbox
 		//fields.add(new MetadataFieldWrapper("CheckBox", true, DataType.Boolean, "false", "Checkbox example", null, null));
 
+
+		// spatial
+	    fields.add(new MetadataFieldWrapper("GeoJson", true, DataTypeWrapper.GeoJSON, "", "", null, null, null));
+
 		// number
-		//fields.add(new MetadataFieldWrapper("Number", true, DataType.Number, "52", "Number example", null, null));
+		fields.add(new MetadataFieldWrapper("Number", true, DataTypeWrapper.Number, "52", "Number example", null, null, null));
 
 		// other number
 		//fields.add(new MetadataFieldWrapper("Number2", true, DataType.Number, null, "Number example 2", null, "[0-9]+"));
@@ -136,7 +199,7 @@ public class CKanMetadataPublisher implements EntryPoint {
 		//		fields.add(new MetadataFieldWrapper("Time intervals 2", true, DataType.Time_Interval, null, "Time intervals 2", null, null));
 
 		// time interval lists
-		fields.add(new MetadataFieldWrapper("Time intervals 2", false, DataType.Times_ListOf, "2010-10-12 15:23", "Time intervals 2", null, null));
+		//fields.add(new MetadataFieldWrapper("Time intervals 2", false, DataType.Times_ListOf, "2010-10-12 15:23", "Time intervals 2", null, null));
 
 		final ArrayList<MetaDataFieldSkeleton> widgetsList = new ArrayList<MetaDataFieldSkeleton>();
 		for (MetadataFieldWrapper metadataFieldWrapper : fields) {
@@ -159,9 +222,9 @@ public class CKanMetadataPublisher implements EntryPoint {
 			public void onClick(ClickEvent event) {
 
 				for (MetaDataFieldSkeleton field : widgetsList) {
-					String error = field.isFieldValueValid();					
+					String error = field.isFieldValueValid();
 					if(error != null)
-						Window.alert(field.getFieldName() + " is not valid. Suggestion: " + error);
+						Window.alert(field.getFieldNameOriginal() + " is not valid. Suggestion: " + error);
 					else
 						Window.alert("No ERROR: " + field.getFieldCurrentValue());
 
@@ -178,18 +241,54 @@ public class CKanMetadataPublisher implements EntryPoint {
 			public void onClick(ClickEvent event) {
 				for (MetaDataFieldSkeleton field : widgetsList)
 					field.freeze();
-			}	
+			}
 		});
 
 	}
 
-
 	@SuppressWarnings("unused")
 	private void startExample() {
 
-		String idFolderWorkspace = "d3a37eb9-1589-4c95-a9d0-c473a02d4f0f";
-		String owner = "costantino.perciante";	
-		RootPanel.get("ckan-metadata-publisher-div").add(new CreateDatasetForm(idFolderWorkspace, eventBus));
+		String idFolderWorkspace = "1fede4e2-5859-4f19-bddb-aec7dd5b632f";
+		RootPanel.get("ckan-metadata-publisher-div").add(new CreateDatasetForm(eventBus));
+
+	}
+
+	// test resources
+	@SuppressWarnings("unused")
+	private void startTwinColumn() {
+
+		TwinColumnSelectionMainPanel resourcesTwinPanel;
+
+		Modal m = new Modal();
+		m.setTitle("Title ......");
+		m.setWidth("1200px");
+		m.getElement().getStyle().setMarginLeft(-30, Unit.PCT);
+		ResourceElementBean r = new ResourceElementBean();
+		r.setFolder(true);
+		r.setName("Root");
+		r.setParent(null);
+		List<ResourceElementBean> children = new ArrayList<ResourceElementBean>();
+
+		// random strings
+		for (int i = 0; i < 10; i++) {
+
+			ResourceElementBean child = new ResourceElementBean();
+			child.setFolder(false);
+			child.setName("BLUE_ECONOMY_WP6_TECHNO_ECONOMIC_ANALYSIS_MODEL.CITE.PPTX" + i);
+			child.setEditableName("BLUE_ECONOMY_WP6_TECHNO_ECONOMIC_ANALYSIS_MODEL.CITE.PPTX" + i);
+			child.setParent(r);
+			child.setFullPath("/" + "BLUE_ECONOMY_WP6_TECHNO_ECONOMIC_ANALYSIS_MODEL.CITE.PPTX" +  + i);
+			children.add(child);
+
+		}
+
+		r.setChildren(children);
+
+		// create random childs
+		resourcesTwinPanel = new TwinColumnSelectionMainPanel(r);
+		m.add(resourcesTwinPanel);
+		m.show();
 
 	}
 }
