@@ -5,6 +5,7 @@ import java.util.List;
 
 import org.gcube.portlets.widgets.ckandatapublisherwidget.client.events.CloseCreationFormEvent;
 import org.gcube.portlets.widgets.ckandatapublisherwidget.client.events.CloseCreationFormEventHandler;
+import org.gcube.portlets.widgets.ckandatapublisherwidget.client.openlayerwidget.GeoJsonAreaSelectionDialog;
 import org.gcube.portlets.widgets.ckandatapublisherwidget.client.ui.metadata.timeandreanges.DataTimeBox;
 import org.gcube.portlets.widgets.ckandatapublisherwidget.client.ui.utils.GcubeDialogExtended;
 import org.gcube.portlets.widgets.ckandatapublisherwidget.shared.metadata.FieldAsGroup;
@@ -12,6 +13,7 @@ import org.gcube.portlets.widgets.ckandatapublisherwidget.shared.metadata.FieldA
 import org.gcube.portlets.widgets.ckandatapublisherwidget.shared.metadata.MetadataFieldWrapper;
 import org.gcube.portlets.widgets.ckandatapublisherwidget.shared.metadata.TaggingGroupingValue;
 
+import com.github.gwtbootstrap.client.ui.Alert;
 import com.github.gwtbootstrap.client.ui.Button;
 import com.github.gwtbootstrap.client.ui.CheckBox;
 import com.github.gwtbootstrap.client.ui.ControlGroup;
@@ -22,6 +24,7 @@ import com.github.gwtbootstrap.client.ui.ListBox;
 import com.github.gwtbootstrap.client.ui.Popover;
 import com.github.gwtbootstrap.client.ui.TextArea;
 import com.github.gwtbootstrap.client.ui.TextBox;
+import com.github.gwtbootstrap.client.ui.constants.AlertType;
 import com.github.gwtbootstrap.client.ui.constants.ControlGroupType;
 import com.github.gwtbootstrap.client.ui.constants.IconType;
 import com.google.gwt.core.client.GWT;
@@ -29,6 +32,7 @@ import com.google.gwt.dom.client.Element;
 import com.google.gwt.dom.client.SpanElement;
 import com.google.gwt.dom.client.Style.Cursor;
 import com.google.gwt.dom.client.Style.Display;
+import com.google.gwt.dom.client.Style.Unit;
 import com.google.gwt.event.dom.client.ClickEvent;
 import com.google.gwt.event.dom.client.ClickHandler;
 import com.google.gwt.event.logical.shared.ResizeEvent;
@@ -37,11 +41,14 @@ import com.google.gwt.event.shared.HandlerManager;
 import com.google.gwt.uibinder.client.UiBinder;
 import com.google.gwt.uibinder.client.UiField;
 import com.google.gwt.uibinder.client.UiHandler;
+import com.google.gwt.user.client.Command;
 import com.google.gwt.user.client.Window;
 import com.google.gwt.user.client.ui.Composite;
 import com.google.gwt.user.client.ui.FlowPanel;
 import com.google.gwt.user.client.ui.FocusPanel;
 import com.google.gwt.user.client.ui.HTML;
+import com.google.gwt.user.client.ui.HorizontalPanel;
+import com.google.gwt.user.client.ui.Label;
 import com.google.gwt.user.client.ui.SimplePanel;
 import com.google.gwt.user.client.ui.VerticalPanel;
 import com.google.gwt.user.client.ui.Widget;
@@ -80,6 +87,8 @@ public class MetaDataFieldSkeleton extends Composite{
 	// range list
 	private List<DataTimeBox> rangesList = new ArrayList<DataTimeBox>();
 
+	private List<TextArea> geoJsonList = new ArrayList<TextArea>();
+
 	// save event bus reference
 	private HandlerManager eventBus;
 
@@ -111,7 +120,7 @@ public class MetaDataFieldSkeleton extends Composite{
 
 		switch(field.getType()){
 
-		case Boolean : 
+		case Boolean :
 
 			// its a checkbox
 			holder = new CheckBox();
@@ -120,7 +129,72 @@ public class MetaDataFieldSkeleton extends Composite{
 			break;
 
 		case GeoJSON:
-		case Text:	
+			//MANAGED By FRANCESCO
+			final VerticalPanel containerGeoJSON = new VerticalPanel();
+			//containerGeoJSON.setWidth("100%");
+
+			final TextArea textArea = new TextArea();
+			textArea.setWidth("100%");
+
+			if(field.getDefaultValue() != null)
+				textArea.setText(field.getDefaultValue());
+
+			containerGeoJSON.add(textArea);
+			
+			HorizontalPanel hp = new HorizontalPanel();
+			hp.getElement().getStyle().setMarginTop(10, Unit.PX);
+			final ListBox geometries = GeoJsonAreaSelectionDialog.getGeometries();
+			
+
+			Button butt = new Button();
+			butt.setIcon(IconType.MAP_MARKER);
+			butt.addClickHandler(new ClickHandler() {
+
+				@Override
+				public void onClick(ClickEvent event) {
+					String geometrySelected = geometries.getSelectedItemText();
+					if(geometrySelected==null) {
+						 containerGeoJSON.add(new Alert("Please, select one geometry", AlertType.WARNING, true));
+					}
+					
+					final GeoJsonAreaSelectionDialog dialog=new GeoJsonAreaSelectionDialog(GeoJsonAreaSelectionDialog.toGeometry(geometrySelected));
+
+					Command fillGeoJSONArea = new Command() {
+						   public void execute() {
+
+							   try {
+								   String geoJsonGeom = dialog.getWKTToGeoJSON();
+								   if(geoJsonGeom!=null)
+									   textArea.setText(geoJsonGeom);
+								   else{
+									   textArea.setText("");
+									   containerGeoJSON.add(new Alert("Sorry, an error occurred by reading the Geometry", AlertType.ERROR, true));
+								   }
+							   }catch (Exception e) {
+								   containerGeoJSON.add(new Alert(e.getMessage(), AlertType.ERROR, true));
+							   }
+						   }
+					};
+
+					dialog.fireCommandOnResponse(fillGeoJSONArea);
+					dialog.center();
+				}
+			});
+
+			geoJsonList.add(textArea);
+			Label label = new Label("Draw a");
+			label.getElement().getStyle().setMarginRight(5, Unit.PX);
+			hp.add(label);
+			geometries.getElement().getStyle().setMarginRight(5, Unit.PX);
+			hp.add(geometries);
+			hp.add(butt);
+			geometries.setItemSelected(0, true);
+			containerGeoJSON.add(hp);
+			holder = containerGeoJSON;
+
+			break;
+
+		case Text:
 
 			holder = new TextArea();
 
@@ -150,7 +224,7 @@ public class MetaDataFieldSkeleton extends Composite{
 			rangesList.add(rangeBox);
 			break;
 
-		case Times_ListOf: 
+		case Times_ListOf:
 
 			holder = new FlowPanel();
 
@@ -161,7 +235,7 @@ public class MetaDataFieldSkeleton extends Composite{
 			SimplePanel panelFirstRange = new SimplePanel();
 			DataTimeBox rangeBoxFirst = new DataTimeBox(true);
 			setRangeTimeInTimeBox(field.getDefaultValue(), rangeBoxFirst);
-			((SimplePanel)panelFirstRange).add(rangeBoxFirst);
+			panelFirstRange.add(rangeBoxFirst);
 			rangesList.add(rangeBoxFirst);
 
 			// Add more button
@@ -347,17 +421,25 @@ public class MetaDataFieldSkeleton extends Composite{
 	 * @return a string with the occurred error on error, null otherwise
 	 */
 	public String isFieldValueValid(){
-
+		
+		try {
+			//Feature #18700
+			String value = getFieldCurrentValue().get(0);
+			if(value.isEmpty())
+				return checkValidator(value, field.getValidator()) ? null : MALFORMED_ATTRIBUTE;
+		}catch (Exception e) {
+			//continue
+		}
+		
 		switch(field.getType()){
 
-		case Boolean : 
+		case Boolean :
 
 			// nothing to validate
 			return null;
 
-		case Text:	
-		case GeoJSON: // validation for geojson will be performed at server side as well TODO
-
+		case Text:
+		case GeoJSON:
 			String textAreaValue = getFieldCurrentValue().get(0);
 
 			if(field.getMandatory()){
@@ -368,7 +450,7 @@ public class MetaDataFieldSkeleton extends Composite{
 					else return checkValidator(textAreaValue, field.getValidator()) ? null : MALFORMED_ATTRIBUTE;
 				else return MANDATORY_ATTRIBUTE_MISSING;
 
-			}else{ 
+			}else{
 
 				if(textAreaValue.trim().isEmpty())
 					return null;
@@ -403,7 +485,7 @@ public class MetaDataFieldSkeleton extends Composite{
 
 			return null;
 
-		case Times_ListOf: 
+		case Times_ListOf:
 
 			for(DataTimeBox el: rangesList){
 
@@ -447,7 +529,7 @@ public class MetaDataFieldSkeleton extends Composite{
 
 		case String:
 
-			// just handle the case of textbox 
+			// just handle the case of textbox
 			if(holder.getClass().equals(TextBox.class)){
 
 				String textBoxValue = getFieldCurrentValue().get(0);
@@ -458,7 +540,7 @@ public class MetaDataFieldSkeleton extends Composite{
 						else return checkValidator(textBoxValue, field.getValidator()) ? null : MALFORMED_ATTRIBUTE;
 					else return MANDATORY_ATTRIBUTE_MISSING;
 
-				}else{ 
+				}else{
 					if(textBoxValue.trim().isEmpty())
 						return null;
 					else return checkValidator(textBoxValue, field.getValidator()) ? null : MALFORMED_ATTRIBUTE;
@@ -467,7 +549,7 @@ public class MetaDataFieldSkeleton extends Composite{
 			else{
 
 				List<String> listboxValues = getFieldCurrentValue();
-				
+
 				if(listboxValues.isEmpty() && field.getMandatory())
 					return MANDATORY_ATTRIBUTE_MISSING;
 
@@ -476,7 +558,7 @@ public class MetaDataFieldSkeleton extends Composite{
 
 						if(field.getValidator() == null || field.getValidator().isEmpty())
 							continue;
-						else 
+						else
 							if(checkValidator(value, field.getValidator()))
 								continue;
 							else return  MALFORMED_ATTRIBUTE;
@@ -533,17 +615,19 @@ public class MetaDataFieldSkeleton extends Composite{
 
 		switch(field.getType()){
 
-		case Boolean : 
+		case Boolean :
 
-			toReturn.add(((CheckBox)holder).getValue().toString()); 
+			toReturn.add(((CheckBox)holder).getValue().toString());
 			break;
 
-		case Text:	
-		case GeoJSON:
-
+		case Text:
 			toReturn.add(((TextArea)holder).getText());
 			break;
 
+		case GeoJSON:
+			toReturn.add(geoJsonList.get(0).getText());
+			break;
+
 		case Time:
 
 			toReturn.add(((DataTimeBox)holder).getCurrentValue().replaceAll(DataTimeBox.MISSING_RANGE_VALUE_START, "")); // it was a noRange metadata
@@ -563,7 +647,7 @@ public class MetaDataFieldSkeleton extends Composite{
 			toReturn.add(manipulatedTemp);
 			break;
 
-		case Times_ListOf: 
+		case Times_ListOf:
 
 			manipulatedTemp = "";
 			for (DataTimeBox elem : rangesList) {
@@ -574,9 +658,9 @@ public class MetaDataFieldSkeleton extends Composite{
 
 				String[] splitted = currentRange.split(DataTimeBox.RANGE_SEPARATOR_START_END);
 				if(splitted[0].equals(splitted[1]))
-					manipulatedTemp += (manipulatedTemp.isEmpty()) ? splitted[0] : RANGE_SEPARATOR  + splitted[0];
+					manipulatedTemp += manipulatedTemp.isEmpty() ? splitted[0] : RANGE_SEPARATOR  + splitted[0];
 					else
-						manipulatedTemp += (manipulatedTemp.isEmpty()) ? splitted[0] + DataTimeBox.RANGE_SEPARATOR_START_END + splitted[1] : 
+						manipulatedTemp += manipulatedTemp.isEmpty() ? splitted[0] + DataTimeBox.RANGE_SEPARATOR_START_END + splitted[1] :
 							RANGE_SEPARATOR + splitted[0] + DataTimeBox.RANGE_SEPARATOR_START_END + splitted[1];
 
 			}
@@ -607,7 +691,7 @@ public class MetaDataFieldSkeleton extends Composite{
 						toReturn.clear();
 						toReturn.add("");
 					}
-			}	
+			}
 
 			break;
 
@@ -647,13 +731,13 @@ public class MetaDataFieldSkeleton extends Composite{
 
 		switch(field.getType()){
 
-		case Boolean : 
+		case Boolean :
 
 			((CheckBox)holder).setEnabled(false);
 			break;
 
 		case GeoJSON:
-		case Text:	
+		case Text:
 
 			((TextArea)holder).setEnabled(false);
 			break;
@@ -668,7 +752,7 @@ public class MetaDataFieldSkeleton extends Composite{
 			rangesList.get(0).freeze();
 			break;
 
-		case Times_ListOf: 
+		case Times_ListOf:
 
 			for(DataTimeBox el : rangesList)
 				el.freeze();
@@ -684,7 +768,7 @@ public class MetaDataFieldSkeleton extends Composite{
 
 			if(holder.getClass().equals(ListBox.class))
 				((ListBox)holder).setEnabled(false);
-			else 
+			else
 				((TextBox)holder).setEnabled(false);
 			break;
 
@@ -782,7 +866,7 @@ public class MetaDataFieldSkeleton extends Composite{
 		}
 		return false;
 	}
-	
+
 	/**
 	 * Check if the propagateUp is set
 	 * @return
